
var app = angular.module('derbyApp', ['ngMaterial','ui.router']);
 
app.run( function() {
  console.log('Derby App Started');
});

app.factory('LocalStorage', ['$window', function($window) {
  return {
    set: function(k,v) {
      localStorage.setItem(k,v);
    },
    setObject: function(k,o) {
      localStorage.setItem(k,angular.toJson(o));
    },
    get: function(k) {
      return localStorage.getItem(k);
    },
    getObject: function(k) {
		let v = localStorage.getItem(k);
		if (v !== 'undefined'){
			return angular.fromJson(v);
		}else{
			return;
		}
    },
	getAll: function() {
		let v = {}
		
		for ( var i = 0, len = localStorage.length; i < len; ++i ) { 
			let k = localStorage.getItem( localStorage.key( i ) );
			if (k !== 'undefined'){
				v[localStorage.key( i )] = angular.fromJson(localStorage.getItem( localStorage.key( i ) )) ;
			}
		}	
      return v
    },
	remove: function(k){
      localStorage.removeItem(k);
    },
    clear: function(){
		localStorage.clear();
    }
  }
}]);

app.factory('httpFactory', [
  '$http',
  '$q',
  function httpFactory($http, $q) {
    console.log('httpService Called');

    // interface
    var derbyService = {
      settings: {},
	  custom: {},
      getSettings: getSettings,
	  getCustom: getCustom,
    };
    return derbyService;

    // implementation
    function getSettings(urls,path) {
      var def = $q.defer();
      var urlCalls = {};
      var key = 0;
      angular.forEach(urls, function(url) {
        urlCalls[key] = $http.get(path + url + '.json');
        key++;
      });
      $q.all(urlCalls).then(function successCallback(settings) {
        derbyService.settings = settings;
        def.resolve(settings);
        //console.log('derbyService Worked', settings);
      }),
        function errorCallback() {
          def.reject('Failed to get settings');
          //console.log('derbyService notworking');
        };
      return def.promise;
    }
	function getCustom(url,path) {
		 var def = $q.defer();
		$http.get(path + url + '.json').then(function successCallback(custom){
				derbyService.custom = custom;
				def.resolve(custom);
		}),
			function errorCallback(){
			def.reject('Failed to get custom');
		};
		return def.promise;
     }
}]);
app.factory('gdVehicleFilter' , ['$q','LocalStorage', function($q,LocalStorage) {
	let modsFound = true;
	let includeMods = null;
	let dataList = []; // Filtered list of vehicles selected  name="Auto Select",type="Model",config2 = "All Config Groups"}
	let dataList2 = []; //Groups the list of config2 and filters
    let dataGroup = {};
	var cList = {};
	let configList = null;
	let modelsList = null;
	let filteredData = {};
	
	 const type = {
		"Heavy Semis" : { semi : 4 },
		"Trucks + Pickups + Vans + SUVs" : { pickup : 4, roamer : 3, van : 4, s10 : 1, durango : 1, '86astro':1},
		"Large Cars": {
			bluebuck : 4, barstow : 4, burnside : 3, fullsize : 4, moonhawk : 4,
			rdpvic : 1, shocker : 1, '76olds': 1, caddy : 1,
			tbird : 1, sui : 1, metric : 1, imperial : 1, yframer:1
		},
		"Mid-Sized Cars" : { hopper : 3, legran : 4, pessima : 4, midsize : 4, sunburst : 3, etki : 4, wendover : 1 },
		"Compact Cars" : { autobello : 3, coupe : 4, hatch : 4, pessima : 4, sunburst : 3, miramar : 4, hopper : 3, wbody : 1, pinto : 1, camry : 1, foxbody : 1 },
		"Luxury + Sports Cars" : { etkc : 4, etk800 : 4, 'super': 3, sbr : 2, vivace : 1 },
		"Pigeon + Piccolina" : { pigeon : 4, autobello : 3, wigeon : 1 },
		"Random": {
			bluebuck : 4, autobello : 3, hopper : 3, pigeon : 4,
			pickup : 4, roamer : 3, van : 4, barstow : 4, burnside : 3, fullsize : 4,
			moonhawk : 4, legran : 4, pessima : 4, midsize : 4, sunburst : 3, coupe : 4, hatch : 4,
			etki : 4, miramar : 4, etkc: 4, etk800 : 4, 'super': 3, sbr : 2, rdpvic : 1, shocker : 1, '76olds': 1,
			wbody : 1, caddy : 1, s10 : 1, tbird : 1, sui : 1, metric : 1, pinto : 1, camry : 1, foxbody : 1, wendover : 1, vivace : 1, wigeon : 1, durango : 1,
			imperial : 1, yframer:1,'86astro':1
		},
	};
	
	function setConfigList() {
		
		var d = $q.defer();
		bngApi.engineLua(`core_vehicles.getConfigList().configs`, (configData) => {
			d.resolve(configData);
		});
		cList = d.promise;
	}
	
	function customClass(vehicleNum) {
		//get a table of all vehicles including mods 
		
		
		//console.log(modelsList);
		let classes = LocalStorage.getObject('classes') || 'Large Cars';
		let config2 = LocalStorage.getObject('config2') ||  'All Config Groups';
		let oppKey = vehicleNum || LocalStorage.getObject('oppKey');
		if (oppKey && Number(oppKey) > 0){
			classes = LocalStorage.getObject(oppKey + 'classes') || 'Large Cars';
			config2 = LocalStorage.getObject(oppKey + 'config2') || 'All Config Groups';
		}
		

		//Filters the list of vehicles
		//Filters the list of vehicles
		//cmodel_key = moonhawk, barstow  
		//ckey = GD-basic-barstow(1)
		//cconfig_type = GD Basic Derby
		function filterClass(cmodel_key,ckey,cconfig_type) {
			let numConfig = 0;
			//Checks if Classes (Large Car, Pigeon/Piccolina) are in the type table then checks if model is found and gets the number of pre setup vehicles.
			if (type[classes][cmodel_key]) {  
				numConfig = type[classes][cmodel_key];
			}
			if (numConfig > 0 || classes == 'Random') { // Bypass if Random selected
				if (!dataList[0]) {
					if (modsFound == true) {
						dataList.push({name : "Auto Select", type : "All Models", config2 : "All Config Groups", preview : null});
					}else{
						dataList.push({name:"Auto Select", type : "No Vehicles Found --Defaults Listed--", config2:"All Config Groups", preview: null});
						modsFound = true;
					}
				}
				if (cconfig_type){ 
					for (let ct in cconfig_type) {  //Config type table (stock, basic, exc)
						dataList.push( {name : ckey, type : cmodel_key, config2 : ct, preview : configList[cmodel_key + "_" + ckey].preview });
					}	
				}else if (ckey.startsWith("GD-")) { 
					let ct = null;
					if (ckey.startsWith("GD-stock")) { 
						ct = "GD Stock Derby";
					}else if(ckey.startsWith("GD-pro")){ 
						ct = "GD Pro Derby";
					}else{
						ct = "GD Basic Derby";
					}
						dataList.push( {name : ckey, type : cmodel_key, config2 : ct, preview : configList[cmodel_key + "_" + ckey].preview });
				}else{
					 dataList.push({name : ckey + ' ' + cmodel_key, type : cmodel_key, config2 : 'unknown', preview : configList[cmodel_key + "_" + ckey].preview  });
				}
			}
		}
		
			
			
		
			for (let k in configList) {
				let c = configList[k];
				if (!c.key.startsWith('v1Normal') && !c.key.startsWith('v1Stripped') && !c.key.startsWith('v1Low-End')){ 
					if (includeMods == 'All Mods and BeamNG - Official') {  //All Mods and Beamng Offical
						if (c.aggregates.Type.Truck || c.aggregates.Type.Car || c.aggregates.Type.Bus || c.aggregates.Type.Automation) {
							filterClass(c.model_key,c.key,c.aggregates['Config Type']);	
						}
					}else{
						if (c.Source == 'Custom' || c.Source == 'Mod') {
							let s = c.key;
							if (includeMods == 'No Mods') { //Default No Mods
							
								if (s.startsWith("GD-")) {
									filterClass(c.model_key, c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'RDP Realistic Derby Project') { //Real Derby Project 
								
								if (s.startsWith("RDP")) {
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'Mini Mania GearGrinder99x') { // Mini Mania by GearGrinder 99x
								if (s.startsWith("MM")) {
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'F150 Mods') {  //F150 Mod
								if (s.startsWith("derby") || s.startsWith("banger") || s.startsWith("duke") || s.startsWith("239a")){
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'Peter Derby Mods') {  //Peter Beamo Mod
								if (s.startsWith("beamo")) {
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'BMH') {  //BMH Mod
								if (s.startsWith ("BMH")) {
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}else if (includeMods == 'All Mods' && c.aggregates.Type.Truck || c.aggregates.Type.Car || c.aggregates.Type.Bus || c.aggregates.Type.Automation) {  //All Mods 
								if ( !s.startsWith("GD-")){  //Don't include No Mods vehicles
									filterClass(c.model_key,c.key,c.aggregates['Config Type']);
								}
							}
						}
					}
				}
			}
		
			
	}
	
	function resetData() {
		dataList = [];
		dataList2 = [];
		dataGroup = {};
	}
	
	function modelName(configData,vehicleNum) {
		if (!configList){
			configList = configData;
		};
		if (modsFound == true) {
			includeMods = LocalStorage.getObject('mods') || 'No Mods';
			let oppKey = vehicleNum || LocalStorage.getObject('oppKey');
			if (oppKey && Number(oppKey) > 0 ) {
				includeMods = LocalStorage.getObject(oppKey + 'mods') || 'No Mods';
			}
		}
		
		let model_key = null;
		let key = null;

		resetData();
	
		customClass(vehicleNum)
		if (!dataList[1] && includeMods != 'No Mods'){
			modsFound = false;
			includeMods = 'No Mods'; 
			modelName();
		}
		let config2List = {};
		let listob = [];
		let groups = [];
		function type_found(tab,val){
			for (let index in tab){  
				let value = tab[index];
				if (value == val) {
					return true;
				}
			}	
			return false
		}
		for (let k in dataList) {
			let item = dataList[k];
			config2List[item.config2] = item.config2
			if  (!type_found(groups,item.type)){
				groups.push(item.type)
			}
		}	
		dataGroup = groups;
		let def = null;
		for (let ct in config2List) {  //Groups the list of config2 
			if (includeMods == 'No Mods') {
				if (ct.startsWith("GD Basic")) {
					def = ct;
				}
			}else{
				if (ct.startsWith("All Config")){
					def = ct;
				}
			}
			listob.push(ct);
		}
		if (!def){  //default is set to All Configs
			def = listob[0];
		}
			dataList2.push({listob : listob, 'default' : def});
			//console.log(dataList)
			//console.log(listob)
			//console.log(dataList2)
			// find what to do here ************************************************
			//gdscenarios.vehList = dataList  //save the dataList  find what to do here
		let vehData = {model : dataList, group : dataGroup};
		filteredData =  {vehicles: vehData, config2 : dataList2}
	}
	setConfigList();
	return{
		modelName:modelName,
		setConfigList:setConfigList,
		getConfigList: function () {return cList;},
		getFilteredData: function () {return filteredData;},
	}
}]);
app.factory('gdMenuService' , ['gdVehicleFilter','$q','LocalStorage','httpFactory','gdSelectionsService', function(gdVehicleFilter,$q,LocalStorage,httpFactory,gdSelectionsService) {
	const urls = ['menus','tracks'];
	  const tracks = {
    arenas: {
      common: {
        main: {
          arena: {
            name: 'Arena',
            default: {
              name: 'Custom',
              type: 'Derby',
            },
            show: 'true',
            tooltip: `'User Created Derby Arena'`,
            laps: {
              name: 'Laps',
              default: 10,
              tooltip: ['# of Laps'],
            },
            listg: [
              {
                name: 'Custom',
                type: 'Derby',
              },
            ],
          },
        },
      },
 
      derby: {
        main: {
          arena: {
            name: 'Arena',
            default: {
              name: 'Grass',
              type: 'Derby',
			  url: 'modules/gdcommon/gdImages/tracks/Grass.jpg',
            },
            show: 'true',
            tooltip: `
              'Concrete Figure 8 Racing - Small narrow figure 8 track',
              'Big 8 Dirt Racing - Large figure 8 track with banked turns',
              'Oval Dirt Racing - Large dirt track',
              'Mud Pit Derby - Grass with mud pits arena',
              'Oval Dirt Derby - Large dirt oval arena',
              'Custom - User Created Derby Arena',
              'Varied Ground Derby - Grass, mud, and concrete arena',
              'Grass Derby - Rectangle grass arena with cement walls',
              'Concrete Derby - Rectangle concrete arena with cement walls',
              "Free Fall Derby - Elevated concrete arena with drop-off's",
            `,
            laps: {
              name: 'Laps',
              default: 10,
              show: 'true',
              tooltip: ['# of Laps'],
            },
            listg: [
              {
                name: 'Grass',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Grass.jpg',
              },
              {
                name: 'Concrete',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Concrete.jpg',
              },
              {
                name: 'Free Fall',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Free Fall.jpg',
              },
              {
                name: 'Varied Ground',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Varied Ground.jpg',
              },
              {
                name: 'Oval Dirt',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Oval Dirt.jpg',
              },
              {
                name: 'Mud Pit',
                type: 'Derby',
				url: 'modules/gdcommon/gdImages/tracks/Mud Pit.jpg',
              },
              {
                name: 'Custom',
                type: 'Derby',
              },
              {
                name: 'Oval Dirt Racing',
                type: 'Racing',
				url: 'modules/gdcommon/gdImages/tracks/Oval Dirt Racing.jpg',
              },
              {
                name: 'Concrete Figure 8',
                type: 'Racing',
				url: 'modules/gdcommon/gdImages/tracks/Concrete Figure 8.jpg',
              },
              {
                name: 'Big 8',
                type: 'Racing',
				url: 'modules/gdcommon/gdImages/tracks/Big 8.jpg',
              },
            ],
          },
        },
      },
    },
  };

	const menus = {
    main: {
      mode: {
        name: 'Mode',
        alt: 'mode',
        default: 'Practice',
        show: 'true',
        icon: 'mode_edit_outline',
        col: 3,
        row: 2,
        tooltip: `
          'Practice - Test your wrecking skills',
          'Season - Earn points for wrecking opponents in each event.  Advance to new divisions based on points earned and skill level.',
        `,
        listng: ['Practice'],
      },
      map: {
        name: 'Map',
        alt: 'map',
        default: 'derby',
        icon: 'map',
        col: 5,
        row: 2,
        show: 'false',
        refresh: ['tracks'],
        tooltip: ['List of Maps'],
        lookup: ['Levels'],
      },
      tracks: {
        name: 'Arenas and Tracks',
        alt: 'tracks',
        default: { name: 'Grass', type: 'Derby' },
        icon: 'map',
        col: 4,
        row: 2,
        show: 'true',
        tooltip: 'Arenas and tracks for each map.',
        lookup: ['tracks'],
      },
      opponents: {
        name: 'Opponents',
        alt: 'opponents',
        default: '3 Vehicles',
        icon: 'directions_car',
        col: 3,
        row: 2,
        show: 'true',
        refresh: ['vehCount'],
        tooltip: `'# of opponents', 'Does not include the player vehicle'`,
        listng: [
          '1 Vehicle',
          '2 Vehicles',
          '3 Vehicles',
          '4 Vehicles',
          '5 Vehicles',
          '6 Vehicles',
          '7 Vehicles',
          '8 Vehicles',
        ],
      },
      classes: {
        name: 'Vehicle Classes',
        alt: 'classes',
        default: 'Large Cars',
        col: 3,
        row: 2,
        show: 'true',
        refresh: ['config2', 'vehicles'],
        tooltip: `
          'Random - Compacts, Mid-Size, Large, Trucks/Pickups/Van/SUVs',
          'Pigeon/Piccolina - Pigeon, Autobello(Piccolina)',
          'Luxury/Sport Cars - ETKC, ETK800, SBR',
          'Large - Barstow, BlueBuck, Fullsize, Moonhawk, Burnside',
          'Compact - Coupe, Hatch, Pessima, Sunburst, Miramar, Hopper, Piccolina',
          "Truck - Pickups/Van/SUV's - Pickup, Van, Roamer",
          'Heavy - Semi',
        `,
        listng: [
          'Random',
          'Pigeon + Piccolina',
          'Luxury + Sports Cars',
          'Compact Cars',
          'Mid-Sized Cars',
          'Large Cars',
          'Trucks + Pickups + Vans + SUVs',
          'Heavy Semis',
        ],
      },
      mods: {
        name: 'Mods',
        alt: 'mods',
        default: 'No Mods',
        col: 3,
        row: 2,
        show: 'true',
        refresh: ['config2', 'vehicles'],
        tooltip: `
          'All Mods and BeamNG - Official - Includes every vehicle in the game include any mods you have installed',
          'Note: This can be combined with Random Class to allow any vehicle in BeamNG to spawn',
          'No Mods - Only includes vehicles that are created by DD-Indeed and Bidwars (Default Setting)',
        `,
        listng: [
          'All Mods and BeamNG - Official',
          'No Mods',
        ],
      },
      config: {
        name: 'Vehicle Config',
        alt: 'config',
        default: 'Normal Config',
        col: 3,
        row: 2,
        show: 'true',
        tooltip: `
          'Normal Config - Loads the parts config file without making changes',
          "Stripped Config - Standard Config without doors (except drivers door), grille's, lettering, and bumpers",
          'Low-End Config - Stripped Config without drivers door, fenders, hood, and trunks',
        `,
        listng: ['Normal Config', 'Stripped Config', 'Low-End Config'],
      },
      config2: {
        name: 'Parts Config',
        alt: 'config2',
        default: 'All Config Groups',
        col: 3,
        row: 2,
        refresh: ['vehicles'],
        show: 'true',
        tooltip: `
          'All Config Groups - System will auto pick vehicles from any of the groups listed',
          'Note:  This list will change based on the mod option selected in the menu',
          'GD Stock Config - No modifications normal vehicles you would find on the street',
          'GD Pro-Derby Config - Higher end derby vehicles include roll cages, heavy bumper steel rims, v8, welded diff',
          'Removes: lights, mirrors, glass, door panels, hubcaps, trim, ext...',
          'GD Basic-Derby Config - Pro-Derby without roll cages, heavy bumpers',
        `,
        listob: ['All Config Groups'],
      },
      vehicles: {
        name: 'Player Vehicle',
        alt: 'vehicles',
        default: {
          name: 'Auto Select',
          type: 'All Models',
        },
        col: 3,
        row: 2,
        show: 'false',
        tooltip: [
          'The vehicle for the player',
          'Auto - Model - Picks at random a vehicle from the drop-down list',
        ],
        listg: [
          {
            name: 'Auto Select',
            type: 'All Models',
          },
        ],
      },
    },
    settings: {
      cdtimer: {
        name: 'Countdown Timer',
        alt: 'cdtimer',
        type: 'range',
        min: 20,
        step: 10,
        max: 200,
        default: 60,
        sign: '#',
        tooltip: 
          `This is the timer used to count out the driver in seconds. 
		  60 seconds is the default value 
		  Note:  The first 30 seconds will not show a warning to the driver.`
		,
        show: 'true',
        refresh: 2,
      },
      heat: {
        name: 'Heats',
        alt: 'heat',
        type: 'checkbox',
        tooltip: 'Heats',
        default: false,
        show: 'true',
        refresh: 2,
      },
      stick: {
        name: 'Show Roof Stick',
        alt: 'stick',
        type: 'checkbox',
        tooltip: 'Show roof sticks on vehicles',
        default: true,
        show: 'false',
        refresh: 2,
      },
      sign: {
        name: 'Show Roof Sign',
        alt: 'sign',
        type: 'checkbox',
        tooltip: 'Show the roof sign with car number',
        default: true,
        show: 'true',
        refresh: 2,
      },
      weld: {
        name: 'Weld Doors, Hood, Trunk',
        alt: 'weld',
        type: 'checkbox',
        tooltip: 'Welding for Doors, Hood, and Trunk',
        default: true,
        show: 'true',
        refresh: 2,
      },
      fire: {
        name: 'Allow Fires',
        alt: 'fire',
        type: 'checkbox',
        tooltip: 'If yes then fires will not automatically extinguish',
        default: false,
        show: 'true',
        refresh: 2,
      },
      fuel: {
        name: 'Allow Fuel Leaks',
        alt: 'fuel',
        type: 'checkbox',
        tooltip: 'If yes then fuel level will drop if gas tank is damaged',
        default: false,
        show: 'true',
        refresh: 2,
      },
      camera: {
        name: 'Driver Camera Auto Rotation Off',
        alt: 'camera',
        type: 'checkbox',
        tooltip:
          'If yes then the interior driver auto camera rotation will be turned off',
        default: false,
        show: 'true',
        refresh: 2,
      },
	  syncplayer:{
		  name: 'Sync Opponents Tab to Player Tab',
		  alt: 'syncplayer',
		  type: 'checkbox',
		  tooltip:
			'If yes then the Opponents Tab will copy the Main Tab Player Configs after each restart of the Scenario and each player change',
			default: true,
			show: 'false',
			refresh: 2,
	  },
      radiator: {
        name: 'Radiator',
        alt: 'radiator',
        type: 'range',
        step: 10,
        min: 0,
        max: 100,
        sign: '%',
        tooltip: `Amount of damage to the radiator before the engine will lock up 
			0% Engine will lock up after any damage to radiator and over heating 
			100% Engine will not lock up`
		,
        default: 10,
        show: 'true',
        refresh: 2,
      },
    },
  };	
	const path = 'modules/gdcommon/gdTabs/';
	var settings = {};
 	var levels = [];
	var trackData = {};
	var vconfig = [];
	var configList = null;
	
	

	function setSettings() {
		settings.menu = {};
		settings.tracks = {};
		settings.menu = menus;
		settings.tracks = tracks;
		//httpFactory.getSettings(urls,path).then(
			//function(setData) {
				//settings.menu = setData[0].data;
				//settings.tracks = setData[1].data;
		//	}
		//);
	}
	function setTracks() {
		trackData = {};
		//const url = 'scenarios/tracks'
		//let p = LocalStorage.getObject('level')
		//let m = '/levels/'+ LocalStorage.getObject('map') + '/'
		//p = p === undefined ? p : m
		//console.log(p + url)
			var d = $q.defer();
			//httpFactory.getCustom(url , p).then(
			//	function(tdata) {
			//	
			//});
		
		bngApi.engineLua('gdcallback.getTracks()', function (tData) {
			d.resolve(tData)
			//console.log(trackData);
		});
		
			trackData = d.promise;
	}
	function saveMenus (init) {
		if (init && init > 0) {
			LocalStorage.setObject('oppKey', init);
		}else{
			LocalStorage.setObject('oppKey', null);
		}
		let options = LocalStorage.getAll();
		
		bngApi.engineLua(`gdscenarios.selection(${bngApi.serializeToLua({options})})`);
	}
	function saveConfigs (vconfigs) {
		let options = LocalStorage.getAll();
		options.vconfigs = vconfigs;
		bngApi.engineLua(`gdscenarios.selection(${bngApi.serializeToLua({options})})`);
			
	}

	function setConfigs (num) {
		var d = $q.defer();
		if (!configList) {		
			gdVehicleFilter.getConfigList().then(function(configData) {
				configList = angular.copy(configData);
				gdVehicleFilter.modelName(configList,num);
				d.resolve(gdVehicleFilter.getFilteredData());
			})
		}else{
			gdVehicleFilter.modelName(configList,num);
			d.resolve(gdVehicleFilter.getFilteredData());
		}
		
		vconfig = d.promise;
		  
		//bngApi.engineLua(`${luaCallbackFunction}(${bngApi.serializeToLua(options)})`,function(vconfigData))
		//bngApi.engineLua('gdcallback.getConfigs(' + bngApi.serializeToLua(options) + ')', function (vconfigData) {
		//	vconfig = vconfigData;
		//		console.log(vconfig);
		//});
	
	}
	function setLevels () {
		getLevelsDataCached((levelsData)=>{
			levels = levelsData;
		 })
		//console.log(levels);
	}
	setTracks();
	setSettings();
	setLevels();
	saveMenus();
	setConfigs();
	
	return{
		setSettings:setSettings,
		setLevels:setLevels,
		setConfigs:setConfigs,
		setTracks:setTracks,
		saveMenus:saveMenus,
		saveConfigs:saveConfigs,
		getSettings: function () { return settings;},
		getLevels: function ()   { return levels;},
		getConfigs: function ()  { return vconfig;},
		getTracks: function ()   { return trackData;},
	};
}]);
app.controller('derbyController', [
	'gdVehicleFilter',
  '$state',
  '$scope',
  'gdMenuService',
  function derbyController( gdVehicleFilter,$state,$scope,gdMenuService) {
    console.log('derbyController Called');
	
	
	
	//$state.go('loading-gd');
	
	//$scope.vidEnded = function(){
      //  console.log('vid ended')
		$state.go(`scenario-gdstart`);
   // }
	$scope.$on('$destroy', function () {
		video.dispose();
	});
  },
]);

